#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

package_dir = \
{'': 'src'}

setup(name='python-rofi-phfn',
      version='1.0.2',
      description='Create simple GUIs using the Rofi application',
      author=None,
      author_email='Paul Hoffmann <phfn@phfn.de>, Blair Bonnett <blair.bonnett@gmail.com>, Marco Köpcke <marco.koepke@tudock.de>',
      url=None,
      py_modules=['rofi'],
      package_dir=package_dir,
     )
